This function creates a YAML file with the placeholder text to define a new
rule. The file is stored in flir/rules/custom. You need to create the
flir folder with setup_flir() if it doesn't exist.
If you want to create a rule that users of your package will be able to
access, use export_new_rule() instead.
add_new_rule(name, path)Create new file(s) but doesn't return anything
Name(s) of the rule. Cannot contain white space.
Path to package or project root. If NULL (default), uses ".".